# Generated by Django 3.0.5 on 2020-05-07 07:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bridger', '0005_auto_20200402_1741'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='endpoint',
            field=models.URLField(blank=True, max_length=2048, null=True),
        ),
    ]
