# from django.db import models

# # Create your models here.
# from bridger.signals.instance_buttons import add_instance_button
# from django.dispatch import receiver
# from tests.viewsets.model_test import ModelTestModelViewSet


# @receiver(add_instance_button, sender=ModelTestModelViewSet)
# def test_adding_instance_buttons(*args, **kwargs):
#     print("==============================")
#     print(args)
#     print(kwargs)
#     print("==============================")
#     return 1
