<!DOCTYPE html>
<html lang="en">

<head>
    <!-- DEFAULTS -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width,initial-scale=1,shrink-to-fit=no">
    <meta name="theme-color" content="#000000">
    <meta http-equiv="Cache-Control" content="no-cache, no-store, must-revalidate" />
    <meta http-equiv="Pragma" content="no-cache" />
    <meta http-equiv="Expires" content="0" />
    <!-- TITLE -->
    <title>{{BRIDGER_CONTEXT.TITLE}}</title>
    <!-- FAVICON -->
    {% if BRIDGER_CONTEXT.FAVICON_URL %}
    <link rel="shortcut icon" type="image/png" href="{{BRIDGER_CONTEXT.FAVICON_URL}}" />
    {% endif %}
    <!-- FONT -->
    <link href="{{BRIDGER_CONTEXT.FONT_URL}}" rel="stylesheet">
    <!-- EXTERNAL CDNS -->
    {% for bridger_cdn_url in BRIDGER_CONTEXT.CDN_URLS %}
    <script src="{{bridger_cdn_url}}"></script>
    {% endfor %}
    <!-- BRIDGER CSS -->
    {% if BRIDGER_CONTEXT.CSS_URL %}
    <link href="{{BRIDGER_CONTEXT.CSS_URL}}" rel="stylesheet" type="text/css">
    {% endif %}

    {% if BRIDGER_CONTEXT.CONFIG_URL %}
    <script type="text/javascript">window.bridger_config_url = "{{BRIDGER_CONTEXT.CONFIG_URL}}"</script>
    {% endif %}
    
</head>

<body><noscript>You need to enable JavaScript to run this app.</noscript>
    <div id="root"></div>
    <!-- BRIDGER JS -->
    {% if BRIDGER_CONTEXT.JS_URL %}
    <script type="application/javascript" src="{{BRIDGER_CONTEXT.JS_URL}}"></script>
    {% endif %}
</body>

</html>