from rest_framework import permissions


class RestAPIModelPermissions(permissions.DjangoModelPermissions):
    """
        Mixin for adding the view permission to the perms_map
        NOTE: This is only here until Django Rest Framework patches
        their DjangoModelPermissions to include view permissions
    """

    perms_map = {
        "GET": ["%(app_label)s.view_%(model_name)s"],
        "OPTIONS": ["%(app_label)s.view_%(model_name)s"],
        "HEAD": ["%(app_label)s.view_%(model_name)s"],
        "POST": ["%(app_label)s.add_%(model_name)s"],
        "PUT": ["%(app_label)s.change_%(model_name)s"],
        "PATCH": ["%(app_label)s.change_%(model_name)s"],
        "DELETE": ["%(app_label)s.delete_%(model_name)s"],
    }
